@echo off

::
:: TARGETDIR parameter must be set to a drive letter located on boot drive 
:: (HD0). This directory is where the files needed to boot IFL will be 
:: placed when setupifl.bat is executed. From this directory a batch file
:: can then be executed to boot into IFL.
::
set TARGETDIR=C:\IFLBOOT

::
:: IFLFILE should be set to the IFL ISO file name to use (iflnet.iso by 
:: default). This file will be looked for at the path defined by the IFLDIR 
:: parameter below, and will be used to copy IFL files from.
::
set IFLFILE=iflnet.iso

::
:: IFLDIR defines the path where the IFL ISO file defined by the IFLFILE 
:: parameter above can be found. The default value below is the default path
:: when when the IFW/IFD/IFL package is installed on 32-bit Windows.
::
set IFLDIR="C:\Program Files\TeraByte Unlimited\Image for Windows\V2\IFL"

:: Uncomment the line below if IFW/IFD/IFL is installed on 64-bit Windows.
:: set IFLDIR="C:\Program Files (x86)\TeraByte Unlimited\Image for Windows\V2\IFL"

::
:: IFLPK is your IFL Product Key, required to run the registered version.
:: Example: set IFLPK=0000-1111-2222
:: If using trial version of IFL, leave this parameter set to default.
::
set IFLPK=XXXX-YYYY-ZZZZ

::
:: IFLBIN is the file name for the bootfile being created in the TARGETDIR
:: defined above. This is the file that bootfile.exe will boot in order to
:: boot into IFL from Windows. This filename will have a .bin extension 
:: added automatically. 
:: Example: set IFLBIN=ifl results in a bootfile named ifl.bin, and the batch
:: file created to boot from ifl.bin will be named run_ifl.bat
::
set IFLBIN=ifl


::-----------------------------------------------------------------------------

::
:: Setup name of windows version of TBOSDT (to support older releases)
::
set TBOSDT=tbosdtw.exe
if not exist ..\win\%TBOSDT% set TBOSDT=tbosdt.exe

::
:: verify directory and files
::
for %%i in (ifl_boot ifl_boot.cfg ifl_boot.tbs setupifl.bat ifl_scripts ..\win\bootfile.exe ..\win\%TBOSDT%) do if not exist %%i goto baddir
for %%i in (%ifldir%\%iflfile%) do if not exist %%i goto badifldir

::
:: create copy of original bootfile with specified file name
:: the file ifl_boot is the template bootfile
::
copy ifl_boot ifl_boot.tmp

::
:: copy iflnet.iso over from specified location
::
copy /y %ifldir%\%iflfile% %iflfile%

::
:: run the ifl_boot.tbs script and pass the Product Key and ISO file name
::
..\win\%TBOSDT% ifl_boot.tbs %iflpk% %iflfile%

::
:: setup target directory
::
if exist %targetdir%\. goto skipmd
md %targetdir% > nul
if not exist %targetdir%\. goto badmd
:skipmd
move /y ifl_boot.tmp %targetdir%\%iflbin%.bin >nul
copy /y ..\win\bootfile.exe %targetdir% >nul
echo %targetdir%\bootfile %targetdir%\%iflbin%.bin > %targetdir%\run_%iflbin%.bat
start %targetdir%
goto end

::
:: report errors
::
:badmd
echo Unable to create target directory %targetdir%
pause
goto end

:baddir
echo This batch file must be launched from the iflsetup folder, which must
echo be a sub-folder of tbosdts_pro. The following files are required to be
echo in the iflsetup folder:
echo ifl_boot
echo ifl_boot.cfg
echo ifl_boot.tbs
echo ifl_scripts (folder)
echo The following files are required to be in the tbosdts_pro\win folder:
echo tbosdtw.exe
echo bootfile.exe
pause
goto end

:badifldir
echo Unable to find the IFL ISO file. 
echo Please check the IFLDIR and IFLFILE variables above
pause
goto end

:end

del %IFLFILE%
set IFLFILE=
set IFLINI=
set IFLPK=
set IFLDIR=
set TARGETDIR=
set TBOSDT=
set IFLBIN=
